pub fn unique_values<T, D>(a: &Array<T, D>) -> FerrayResult<Array<T, Ix1>>Expand description
Sorted unique values of the (flattened) array.
Array-API-standard alias for unique with no extra return arrays.
Equivalent to numpy.unique_values(x).
pub fn unique_values<T, D>(a: &Array<T, D>) -> FerrayResult<Array<T, Ix1>>Sorted unique values of the (flattened) array.
Array-API-standard alias for unique with no extra return arrays.
Equivalent to numpy.unique_values(x).