Module sorting

Module sorting 

Enums

Side
Side parameter for searchsorted.
SortKind
Sorting algorithm selection.

Functions

argsort
Return the indices that would sort an array along the given axis.
searchsorted
Find indices where elements should be inserted to maintain order.
sort
Sort an array along the given axis (or flattened if axis is None).