pub fn sort<T, D>(
a: &Array<T, D>,
axis: Option<usize>,
kind: SortKind,
) -> FerrayResult<Array<T, IxDyn>>Expand description
Sort an array along the given axis (or flattened if axis is None).
When axis is None, the array is flattened before sorting and a 1-D
array is returned (matching NumPy behaviour). When an axis is given, the
returned array has the same shape as the input.
Equivalent to numpy.sort.